#
# ObjectFactories
#
# Default object factories
#
# Copyright (c) 2001-2003 by Philipp "philiKON" von Weitershausen
#
# This software is distributed under the terms of the Mozilla Public License
# (MPL)
#

"""
$Id: ObjectFactories.py,v 1.4 2003/01/26 13:38:02 philipp Exp $
"""

#
# Available factories:
#
# DTML Method
# DTML Document
# Page Template
# File
# Script (Python)
# Z SQL Method
# Parsed XML
#

from IObjectFactory import IObjectFactory
from FactoryRegistry import FactoryRegistry

class DTMLMethodFactory:

    __implements__ = IObjectFactory

    def createObject(self, id, title, data, **kw):
        from OFS.DTMLMethod import DTMLMethod
        resultObj = DTMLMethod(data, __name__=id)
        resultObj.id = id
        resultObj.title = title
        for name, value in kw.items():
            setattr(resultObj, name, value)
        return resultObj

DTMLMethodFactory = DTMLMethodFactory()
FactoryRegistry.register("DTML Method", DTMLMethodFactory)

class DTMLDocumentFactory:

    __implements__ = IObjectFactory

    def createObject(self, id, title, data, **kw):
        from OFS.DTMLDocument import DTMLDocument
        resultObj = DTMLDocument(data, __name__=id)
        resultObj.id = id
        resultObj.title = title
        for name, value in kw.items():
            setattr(resultObj, name, value)
        return resultObj

DTMLDocumentFactory = DTMLDocumentFactory()
FactoryRegistry.register("DTML Document", DTMLDocumentFactory)

class ZPTFactory:

    __implements__ = IObjectFactory

    def createObject(self, id, title, data, **kw):
        from Products.PageTemplates.ZopePageTemplate import ZopePageTemplate
        content_type = kw.get('content_type', 'text/html')
        resultObj = ZopePageTemplate(id, data, content_type)
        resultObj.pt_setTitle(title)
        for name, value in kw.items():
            setattr(resultObj, name, value)
        return resultObj

ZPTFactory = ZPTFactory()
FactoryRegistry.register("Page Template", ZPTFactory)

class FileFactory:

    __implements__ = IObjectFactory

    def createObject(self, id, title, data, **kw):
        from OFS.Image import File
        content_type = kw.get('content_type', None)
        resultObj = File(id, title, data, content_type)
        for name, value in kw.items():
            setattr(resultObj, name, value)
        return resultObj

FileFactory = FileFactory()
FactoryRegistry.register("File", FileFactory)

class ImageFactory:

    __implements__ = IObjectFactory

    def createObject(self, id, title, data, **kw):
        from OFS.Image import Image
        content_type = kw.get('content_type', None)
        resultObj = Image(id, title, data, content_type)
        for name, value in kw.items():
            setattr(resultObj, name, value)
        return resultObj

ImageFactory = ImageFactory()
FactoryRegistry.register("Image", ImageFactory)

class PythonScriptFactory:
    
    __implements__ = IObjectFactory

    def createObject(self, id, title, data, **kw):
        from Products.PythonScripts.PythonScript import PythonScript
        resultObj = PythonScript(id)
        resultObj.write(data)
        resultObj.title = title
        return resultObj
    
PythonScriptFactory = PythonScriptFactory()
FactoryRegistry.register("Script (Python)", PythonScriptFactory)

class ZSQLMethodFactory:

    __implements__ = IObjectFactory

    def createObject(self, id, title, data, **kw):
        from Products.ZSQLMethods.SQL import SQL
        connection_id = kw.get('conntection_id', '')
        arguments = kw.get('arguments', '')
        resultObj = SQL(id, title, connection_id, arguments, data)
        for name, value in kw.items():
            setattr(resultObj, name, value)
        return resultObj

ZSQLMethodFactory = ZSQLMethodFactory()
FactoryRegistry.register("Z SQL Method", ZSQLMethodFactory)

class ParsedXMLFactory:
    
    __implements__ = IObjectFactory

    def createObject(self, id, title, data, **kw):
        from Products.ParsedXML.ParsedXML import ParsedXML
        content_type = kw.get('content_type', 'text/xml')
        resultObj = ParsedXML(id, data, contentType=content_type)
        for name, value in kw.items():
            setattr(resultObj, name, value)
        return resultObj

ParsedXMLFactory = ParsedXMLFactory()
try:
    import Products.ParsedXML
    FactoryRegistry.register("Parsed XML", ParsedXMLFactory)
except ImportError:
    pass
