
"""
$Id: testCVSWrapper.py,v 1.6 2003/02/18 21:30:41 philipp Exp $
"""

import os, sys, time
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Testing import ZopeTestCase
import Interface
from Products.RevisionManager.CVSWrapper import CVSWrapper, CVSError
from Products.RevisionManager.IRevisionController import IRevisionController

ZopeTestCase.installProduct('RevisionManager')

MODULE = "PythonUnittest"
PREFIX = os.path.join("/tmp", "testRevisionManager-"+str(int(time.time())))
WORK_DIR = os.path.join(PREFIX, "workdir")
REPOSITORY_PATH = os.path.join(PREFIX, "repository")

class CVSWrapperTest(ZopeTestCase.ZopeTestCase):

    def __init__(self, method_name='runTest'):
        ZopeTestCase.ZopeTestCase.__init__(self, method_name)
        self.module = MODULE
        self.work_dir = WORK_DIR
        self.repository_path = REPOSITORY_PATH
        if not os.path.isdir(PREFIX):
            os.mkdir(PREFIX)
        if not os.path.isdir(self.work_dir):
            os.mkdir(self.work_dir)
        self.cvs_wrapper = CVSWrapper(module=self.module, work_dir=self.work_dir,
                                      repository_path=self.repository_path)

    def __del__(self):
        os.system("rm -Rf %s" % PREFIX)
    
    def test01_verify_interface(self):
        """Verify interface implementation"""
        from Interface.Verify import verifyClass
        self.failUnless(verifyClass(IRevisionController, CVSWrapper))

    def test02_import(self):
        """Test import functionality"""
        cvs = self.cvs_wrapper
        cvs.init_repository()
        cvs.import_module("./testfiles", "UNITTEST", "UNITTEST_1", "Python Unittest Import")
        orig_file = os.path.join(os.path.dirname(__file__), 'testfiles', 'helloworld.txt')
        orig_contents = open(orig_file).read()
        revision_file = os.path.join(self.repository_path, self.module, "helloworld.txt,v")
        revision_contents = open(revision_file).read()
        self.failUnless(revision_contents.find(orig_contents) != -1)
        
    def test03_checkout(self):
        """Test checkout functionality"""
        cvs = self.cvs_wrapper
        cvs.checkout()
        orig_file = os.path.join(os.path.dirname(__file__), 'testfiles', 'helloworld.txt')
        orig_contents = open(orig_file).read()
        checkout_file = os.path.join(self.work_dir, self.module, "helloworld.txt")
        checkout_contents = open(checkout_file).read()
        self.failUnless(checkout_contents == orig_contents)

    def test04_update_commit(self):
        """Test update/commit functionality"""
        # locally modified file
        string = "Hello CVS world!"
        cvs = self.cvs_wrapper
        filename = os.path.join(self.work_dir, self.module, "helloworld.txt")
        fp = open(filename, "w")
        fp.write(string)
        fp.close()
        d = {'helloworld.txt':'Locally Modified'}
        self.assertEqual(cvs.update(), d)
        cvs.commit()

    def test05_addfile_commit(self):
        """Test add/commit functionality"""
        # unknown file
        string = "Let it be!"
        cvs = self.cvs_wrapper
        filename = os.path.join(self.work_dir, self.module, "letitbe.txt")
        fp = open(filename, "w")
        fp.write(string)
        fp.close()
        d = {'letitbe.txt':'Unknown'}
        self.assertEqual(cvs.update(), d)

        # to-be-added file
        cvs.add("letitbe.txt")
        d = {'letitbe.txt':'To be added'}
        self.assertEqual(cvs.update(), d)
        cvs.commit()

    def test06_tag(self):
        """Test tag"""
        cvs = self.cvs_wrapper
        cvs.tag("LETITBE", 'letitbe.txt')
        # test09 checks whether tag succeeded

    def test07_status(self):
        """Test status"""
        cvs = self.cvs_wrapper
        status = cvs.status()
        self.failUnless(status.has_key('letitbe.txt'))
        status = status['letitbe.txt']
        self.failUnless(status.has_key('filename'))
        self.assertEqual(status['filename'], 'letitbe.txt')
        self.failUnless(status.has_key('status'))
        self.failUnless(status.has_key('wrev'))
        self.failUnless(status.has_key('rrev'))
        self.failUnless(status.has_key('stag'))
        self.failUnless(status.has_key('sdate'))
        self.failUnless(status.has_key('sopt'))

    def test08_log(self):
        """Test log"""
        cvs = self.cvs_wrapper
        log = cvs.log()
        self.failUnless(log.has_key('letitbe.txt'))
        log = log['letitbe.txt']
        self.failUnless(log.has_key('tags'))
        self.failUnless(log['tags'].has_key('LETITBE'))
        self.failUnless(log.has_key('revisions'))
        rev = log['revisions']
        self.failUnless(len(rev))
        rev = rev[0]
        self.failUnless(rev.has_key('revision'))
        self.failUnless(rev.has_key('date'))
        self.failUnless(rev.has_key('author'))
        self.failUnless(rev.has_key('state'))
        self.failUnless(rev.has_key('log'))
        self.failUnless(rev.has_key('branches'))
        self.failUnless(rev.has_key('lines'))

    def test09_diff(self):
        """Test diff"""
        cvs = self.cvs_wrapper
        log = cvs.log()
        log = log['helloworld.txt']
        rev1 = log['revisions'][0]['revision']
        rev2 = log['revisions'][1]['revision']
        diff = cvs.diff('helloworld.txt', rev1, rev2)
        self.assertEqual(type(diff), type(''))
        self.failUnless(len(diff))

    def test10_error(self):
        """Test error handling"""
        # make a CVSWrapper instance that is destined to break
        cvs = CVSWrapper(work_dir=self.work_dir)
        self.assertRaises(CVSError, cvs.checkout)

if __name__ == '__main__':
    framework(descriptions=1, verbosity=2)
else:
    import unittest
    def test_suite():
        suite = unittest.TestSuite()
        suite.addTest(unittest.makeSuite(CVSWrapperTest))
        return suite
